==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/workloads/kotlin/inputs/DBBackupPolicyPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.workloads.kotlin.inputs

import com.pulumi.azurenative.workloads.inputs.DBBackupPolicyPropertiesArgs.builder
import com.pulumi.azurenative.workloads.kotlin.enums.WorkloadType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Defines the policy properties for database backup.
 * @property backupManagementType This property will be used as the discriminator for deciding the specific types in the polymorphic chain of types.
 * Expected value is 'AzureWorkload'.
 * @property makePolicyConsistent Fix the policy inconsistency
 * @property name The name of the DB backup policy.
 * @property protectedItemsCount Number of items associated with this policy.
 * @property resourceGuardOperationRequests ResourceGuard Operation Requests
 * @property settings Common settings for the backup management
 * @property subProtectionPolicy List of sub-protection policies which includes schedule and retention
 * @property workLoadType Type of workload for the backup management
 */
public data class DBBackupPolicyPropertiesArgs(
    public val backupManagementType: Output<String>,
    public val makePolicyConsistent: Output<Boolean>? = null,
    public val name: Output<String>,
    public val protectedItemsCount: Output<Int>? = null,
    public val resourceGuardOperationRequests: Output<List<String>>? = null,
    public val settings: Output<SettingsArgs>? = null,
    public val subProtectionPolicy: Output<List<SubProtectionPolicyArgs>>? = null,
    public val workLoadType: Output<Either<String, WorkloadType>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.workloads.inputs.DBBackupPolicyPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.workloads.inputs.DBBackupPolicyPropertiesArgs =
        com.pulumi.azurenative.workloads.inputs.DBBackupPolicyPropertiesArgs.builder()
            .backupManagementType(backupManagementType.applyValue({ args0 -> args0 }))
            .makePolicyConsistent(makePolicyConsistent?.applyValue({ args0 -> args0 }))
            .name(name.applyValue({ args0 -> args0 }))
            .protectedItemsCount(protectedItemsCount?.applyValue({ args0 -> args0 }))
            .resourceGuardOperationRequests(
                resourceGuardOperationRequests?.applyValue({ args0 ->
                    args0.map({ args0 -> args0 })
                }),
            )
            .settings(settings?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .subProtectionPolicy(
                subProtectionPolicy?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .workLoadType(
                workLoadType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [DBBackupPolicyPropertiesArgs].
 */
@PulumiTagMarker
public class DBBackupPolicyPropertiesArgsBuilder internal constructor() {
    private var backupManagementType: Output<String>? = null

    private var makePolicyConsistent: Output<Boolean>? = null

    private var name: Output<String>? = null

    private var protectedItemsCount: Output<Int>? = null

    private var resourceGuardOperationRequests: Output<List<String>>? = null

    private var settings: Output<SettingsArgs>? = null

    private var subProtectionPolicy: Output<List<SubProtectionPolicyArgs>>? = null

    private var workLoadType: Output<Either<String, WorkloadType>>? = null

    /**
     * @param value This property will be used as the discriminator for deciding the specific types in the polymorphic chain of types.
     * Expected value is 'AzureWorkload'.
     */
    @JvmName("srcndcunyaxcklrs")
    public suspend fun backupManagementType(`value`: Output<String>) {
        this.backupManagementType = value
    }

    /**
     * @param value Fix the policy inconsistency
     */
    @JvmName("mbvswbwcvnuavtxm")
    public suspend fun makePolicyConsistent(`value`: Output<Boolean>) {
        this.makePolicyConsistent = value
    }

    /**
     * @param value The name of the DB backup policy.
     */
    @JvmName("phdvwavlytjsqbjx")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Number of items associated with this policy.
     */
    @JvmName("jqfjwbrpdvqcyxib")
    public suspend fun protectedItemsCount(`value`: Output<Int>) {
        this.protectedItemsCount = value
    }

    /**
     * @param value ResourceGuard Operation Requests
     */
    @JvmName("lpltrcgaexohovoi")
    public suspend fun resourceGuardOperationRequests(`value`: Output<List<String>>) {
        this.resourceGuardOperationRequests = value
    }

    @JvmName("qijosiqpatgywyek")
    public suspend fun resourceGuardOperationRequests(vararg values: Output<String>) {
        this.resourceGuardOperationRequests = Output.all(values.asList())
    }

    /**
     * @param values ResourceGuard Operation Requests
     */
    @JvmName("fjfuatsopikxxubb")
    public suspend fun resourceGuardOperationRequests(values: List<Output<String>>) {
        this.resourceGuardOperationRequests = Output.all(values)
    }

    /**
     * @param value Common settings for the backup management
     */
    @JvmName("lronllnxajlobcix")
    public suspend fun settings(`value`: Output<SettingsArgs>) {
        this.settings = value
    }

    /**
     * @param value List of sub-protection policies which includes schedule and retention
     */
    @JvmName("duqmkvvtsxungdgt")
    public suspend fun subProtectionPolicy(`value`: Output<List<SubProtectionPolicyArgs>>) {
        this.subProtectionPolicy = value
    }

    @JvmName("poimsdxubngvdbui")
    public suspend fun subProtectionPolicy(vararg values: Output<SubProtectionPolicyArgs>) {
        this.subProtectionPolicy = Output.all(values.asList())
    }

    /**
     * @param values List of sub-protection policies which includes schedule and retention
     */
    @JvmName("knnshdtneyuslsyv")
    public suspend fun subProtectionPolicy(values: List<Output<SubProtectionPolicyArgs>>) {
        this.subProtectionPolicy = Output.all(values)
    }

    /**
     * @param value Type of workload for the backup management
     */
    @JvmName("xemapwjakbfonkpa")
    public suspend fun workLoadType(`value`: Output<Either<String, WorkloadType>>) {
        this.workLoadType = value
    }

    /**
     * @param value This property will be used as the discriminator for deciding the specific types in the polymorphic chain of types.
     * Expected value is 'AzureWorkload'.
     */
    @JvmName("rtrvsiimswggtxau")
    public suspend fun backupManagementType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.backupManagementType = mapped
    }

    /**
     * @param value Fix the policy inconsistency
     */
    @JvmName("swuvldcrxoounevl")
    public suspend fun makePolicyConsistent(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.makePolicyConsistent = mapped
    }

    /**
     * @param value The name of the DB backup policy.
     */
    @JvmName("jnhhyoscumytkmbk")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Number of items associated with this policy.
     */
    @JvmName("reksgruosjrbmejg")
    public suspend fun protectedItemsCount(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.protectedItemsCount = mapped
    }

    /**
     * @param value ResourceGuard Operation Requests
     */
    @JvmName("foxjbirfynecoqie")
    public suspend fun resourceGuardOperationRequests(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGuardOperationRequests = mapped
    }

    /**
     * @param values ResourceGuard Operation Requests
     */
    @JvmName("fkdmuvcfxwjckqbw")
    public suspend fun resourceGuardOperationRequests(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resourceGuardOperationRequests = mapped
    }

    /**
     * @param value Common settings for the backup management
     */
    @JvmName("gsmjocpytarkfumc")
    public suspend fun settings(`value`: SettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.settings = mapped
    }

    /**
     * @param argument Common settings for the backup management
     */
    @JvmName("bdvmbmankifybwlv")
    public suspend fun settings(argument: suspend SettingsArgsBuilder.() -> Unit) {
        val toBeMapped = SettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.settings = mapped
    }

    /**
     * @param value List of sub-protection policies which includes schedule and retention
     */
    @JvmName("uylrrbptjjekucdb")
    public suspend fun subProtectionPolicy(`value`: List<SubProtectionPolicyArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.subProtectionPolicy = mapped
    }

    /**
     * @param argument List of sub-protection policies which includes schedule and retention
     */
    @JvmName("ovfxrdqfbqlatnyo")
    public suspend
    fun subProtectionPolicy(argument: List<suspend SubProtectionPolicyArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            SubProtectionPolicyArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.subProtectionPolicy = mapped
    }

    /**
     * @param argument List of sub-protection policies which includes schedule and retention
     */
    @JvmName("ukcmogurkcjtfuqi")
    public suspend fun subProtectionPolicy(
        vararg
        argument: suspend SubProtectionPolicyArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            SubProtectionPolicyArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.subProtectionPolicy = mapped
    }

    /**
     * @param argument List of sub-protection policies which includes schedule and retention
     */
    @JvmName("shumpknpajdyinbj")
    public suspend
    fun subProtectionPolicy(argument: suspend SubProtectionPolicyArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(SubProtectionPolicyArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.subProtectionPolicy = mapped
    }

    /**
     * @param values List of sub-protection policies which includes schedule and retention
     */
    @JvmName("qckliianjrelcvcr")
    public suspend fun subProtectionPolicy(vararg values: SubProtectionPolicyArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.subProtectionPolicy = mapped
    }

    /**
     * @param value Type of workload for the backup management
     */
    @JvmName("oxasxgjghpveximb")
    public suspend fun workLoadType(`value`: Either<String, WorkloadType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.workLoadType = mapped
    }

    /**
     * @param value Type of workload for the backup management
     */
    @JvmName("fyhduykvrlpvgjou")
    public fun workLoadType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, WorkloadType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.workLoadType = mapped
    }

    /**
     * @param value Type of workload for the backup management
     */
    @JvmName("sgcdcpahqlmsorxi")
    public fun workLoadType(`value`: WorkloadType) {
        val toBeMapped = Either.ofRight<String, WorkloadType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.workLoadType = mapped
    }

    internal fun build(): DBBackupPolicyPropertiesArgs = DBBackupPolicyPropertiesArgs(
        backupManagementType = backupManagementType ?: throw
            PulumiNullFieldException("backupManagementType"),
        makePolicyConsistent = makePolicyConsistent,
        name = name ?: throw PulumiNullFieldException("name"),
        protectedItemsCount = protectedItemsCount,
        resourceGuardOperationRequests = resourceGuardOperationRequests,
        settings = settings,
        subProtectionPolicy = subProtectionPolicy,
        workLoadType = workLoadType,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/workloads/kotlin/inputs/DBBackupPolicyPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.workloads.kotlin.inputs

import com.pulumi.azurenative.workloads.inputs.DBBackupPolicyPropertiesArgs.builder
import com.pulumi.azurenative.workloads.kotlin.enums.WorkloadType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Defines the policy properties for database backup.
 * @property backupManagementType This property will be used as the discriminator for deciding the specific types in the polymorphic chain of types.
 * Expected value is 'AzureWorkload'.
 * @property makePolicyConsistent Fix the policy inconsistency
 * @property name The name of the DB backup policy.
 * @property protectedItemsCount Number of items associated with this policy.
 * @property resourceGuardOperationRequests ResourceGuard Operation Requests
 * @property settings Common settings for the backup management
 * @property subProtectionPolicy List of sub-protection policies which includes schedule and retention
 * @property workLoadType Type of workload for the backup management
 */
public data class DBBackupPolicyPropertiesArgs(
    public val backupManagementType: Output<String>,
    public val makePolicyConsistent: Output<Boolean>? = null,
    public val name: Output<String>,
    public val protectedItemsCount: Output<Int>? = null,
    public val resourceGuardOperationRequests: Output<List<String>>? = null,
    public val settings: Output<SettingsArgs>? = null,
    public val subProtectionPolicy: Output<List<SubProtectionPolicyArgs>>? = null,
    public val workLoadType: Output<Either<String, WorkloadType>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.workloads.inputs.DBBackupPolicyPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.workloads.inputs.DBBackupPolicyPropertiesArgs =
        com.pulumi.azurenative.workloads.inputs.DBBackupPolicyPropertiesArgs.builder()
            .backupManagementType(backupManagementType.applyValue({ args0 -> args0 }))
            .makePolicyConsistent(makePolicyConsistent?.applyValue({ args0 -> args0 }))
            .name(name.applyValue({ args0 -> args0 }))
            .protectedItemsCount(protectedItemsCount?.applyValue({ args0 -> args0 }))
            .resourceGuardOperationRequests(
                resourceGuardOperationRequests?.applyValue({ args0 ->
                    args0.map({ args0 -> args0 })
                }),
            )
            .settings(settings?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .subProtectionPolicy(
                subProtectionPolicy?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .workLoadType(
                workLoadType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [DBBackupPolicyPropertiesArgs].
 */
@PulumiTagMarker
public class DBBackupPolicyPropertiesArgsBuilder internal constructor() {
    private var backupManagementType: Output<String>? = null

    private var makePolicyConsistent: Output<Boolean>? = null

    private var name: Output<String>? = null

    private var protectedItemsCount: Output<Int>? = null

    private var resourceGuardOperationRequests: Output<List<String>>? = null

    private var settings: Output<SettingsArgs>? = null

    private var subProtectionPolicy: Output<List<SubProtectionPolicyArgs>>? = null

    private var workLoadType: Output<Either<String, WorkloadType>>? = null

    /**
     * @param value This property will be used as the discriminator for deciding the specific types in the polymorphic chain of types.
     * Expected value is 'AzureWorkload'.
     */
    @JvmName("aguccyhjaxeyohxm")
    public suspend fun backupManagementType(`value`: Output<String>) {
        this.backupManagementType = value
    }

    /**
     * @param value Fix the policy inconsistency
     */
    @JvmName("wylglwawckpohhvt")
    public suspend fun makePolicyConsistent(`value`: Output<Boolean>) {
        this.makePolicyConsistent = value
    }

    /**
     * @param value The name of the DB backup policy.
     */
    @JvmName("axdfyolmdaaqyogx")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Number of items associated with this policy.
     */
    @JvmName("lsncqqdsvsjhdqxm")
    public suspend fun protectedItemsCount(`value`: Output<Int>) {
        this.protectedItemsCount = value
    }

    /**
     * @param value ResourceGuard Operation Requests
     */
    @JvmName("ykdrkbyblwisxcli")
    public suspend fun resourceGuardOperationRequests(`value`: Output<List<String>>) {
        this.resourceGuardOperationRequests = value
    }

    @JvmName("dtqrkyewyyclewvu")
    public suspend fun resourceGuardOperationRequests(vararg values: Output<String>) {
        this.resourceGuardOperationRequests = Output.all(values.asList())
    }

    /**
     * @param values ResourceGuard Operation Requests
     */
    @JvmName("chaefdjyehoeanmd")
    public suspend fun resourceGuardOperationRequests(values: List<Output<String>>) {
        this.resourceGuardOperationRequests = Output.all(values)
    }

    /**
     * @param value Common settings for the backup management
     */
    @JvmName("fdklrpnifmamqwnr")
    public suspend fun settings(`value`: Output<SettingsArgs>) {
        this.settings = value
    }

    /**
     * @param value List of sub-protection policies which includes schedule and retention
     */
    @JvmName("eretmwcpgpdfjxdu")
    public suspend fun subProtectionPolicy(`value`: Output<List<SubProtectionPolicyArgs>>) {
        this.subProtectionPolicy = value
    }

    @JvmName("cljtsnvkxviqtcxj")
    public suspend fun subProtectionPolicy(vararg values: Output<SubProtectionPolicyArgs>) {
        this.subProtectionPolicy = Output.all(values.asList())
    }

    /**
     * @param values List of sub-protection policies which includes schedule and retention
     */
    @JvmName("rksnfbyndmqtwdhk")
    public suspend fun subProtectionPolicy(values: List<Output<SubProtectionPolicyArgs>>) {
        this.subProtectionPolicy = Output.all(values)
    }

    /**
     * @param value Type of workload for the backup management
     */
    @JvmName("ywuhrmoxmyfewbhy")
    public suspend fun workLoadType(`value`: Output<Either<String, WorkloadType>>) {
        this.workLoadType = value
    }

    /**
     * @param value This property will be used as the discriminator for deciding the specific types in the polymorphic chain of types.
     * Expected value is 'AzureWorkload'.
     */
    @JvmName("yuubavbkrpnfmnxa")
    public suspend fun backupManagementType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.backupManagementType = mapped
    }

    /**
     * @param value Fix the policy inconsistency
     */
    @JvmName("gykacbqetvadworb")
    public suspend fun makePolicyConsistent(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.makePolicyConsistent = mapped
    }

    /**
     * @param value The name of the DB backup policy.
     */
    @JvmName("jgofhhlrcuddmstp")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Number of items associated with this policy.
     */
    @JvmName("tydbpyxdmyemhdgd")
    public suspend fun protectedItemsCount(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.protectedItemsCount = mapped
    }

    /**
     * @param value ResourceGuard Operation Requests
     */
    @JvmName("dtwfcvfeamnecxdh")
    public suspend fun resourceGuardOperationRequests(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGuardOperationRequests = mapped
    }

    /**
     * @param values ResourceGuard Operation Requests
     */
    @JvmName("cwwtiyedbpgexyui")
    public suspend fun resourceGuardOperationRequests(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resourceGuardOperationRequests = mapped
    }

    /**
     * @param value Common settings for the backup management
     */
    @JvmName("yigvssogcbxumija")
    public suspend fun settings(`value`: SettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.settings = mapped
    }

    /**
     * @param argument Common settings for the backup management
     */
    @JvmName("rqhkowcasjooepbi")
    public suspend fun settings(argument: suspend SettingsArgsBuilder.() -> Unit) {
        val toBeMapped = SettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.settings = mapped
    }

    /**
     * @param value List of sub-protection policies which includes schedule and retention
     */
    @JvmName("gaucvlhsnmssoqkh")
    public suspend fun subProtectionPolicy(`value`: List<SubProtectionPolicyArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.subProtectionPolicy = mapped
    }

    /**
     * @param argument List of sub-protection policies which includes schedule and retention
     */
    @JvmName("dinkxgdqxgoiskva")
    public suspend
    fun subProtectionPolicy(argument: List<suspend SubProtectionPolicyArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            SubProtectionPolicyArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.subProtectionPolicy = mapped
    }

    /**
     * @param argument List of sub-protection policies which includes schedule and retention
     */
    @JvmName("xkrtitaxqdbaikno")
    public suspend fun subProtectionPolicy(
        vararg
        argument: suspend SubProtectionPolicyArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            SubProtectionPolicyArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.subProtectionPolicy = mapped
    }

    /**
     * @param argument List of sub-protection policies which includes schedule and retention
     */
    @JvmName("uxrklhjnlfoouraw")
    public suspend
    fun subProtectionPolicy(argument: suspend SubProtectionPolicyArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(SubProtectionPolicyArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.subProtectionPolicy = mapped
    }

    /**
     * @param values List of sub-protection policies which includes schedule and retention
     */
    @JvmName("ahmiqerrinykijuk")
    public suspend fun subProtectionPolicy(vararg values: SubProtectionPolicyArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.subProtectionPolicy = mapped
    }

    /**
     * @param value Type of workload for the backup management
     */
    @JvmName("bwftvhygcphiujch")
    public suspend fun workLoadType(`value`: Either<String, WorkloadType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.workLoadType = mapped
    }

    /**
     * @param value Type of workload for the backup management
     */
    @JvmName("blwcjhxevkbdpiha")
    public fun workLoadType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, WorkloadType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.workLoadType = mapped
    }

    /**
     * @param value Type of workload for the backup management
     */
    @JvmName("nwbjsqijkqgiybyi")
    public fun workLoadType(`value`: WorkloadType) {
        val toBeMapped = Either.ofRight<String, WorkloadType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.workLoadType = mapped
    }

    internal fun build(): DBBackupPolicyPropertiesArgs = DBBackupPolicyPropertiesArgs(
        backupManagementType = backupManagementType ?: throw
            PulumiNullFieldException("backupManagementType"),
        makePolicyConsistent = makePolicyConsistent,
        name = name ?: throw PulumiNullFieldException("name"),
        protectedItemsCount = protectedItemsCount,
        resourceGuardOperationRequests = resourceGuardOperationRequests,
        settings = settings,
        subProtectionPolicy = subProtectionPolicy,
        workLoadType = workLoadType,
    )
}
